pub struct AiModelsConfig {
pub suggest: String,
pub fix: String,
pub import: String,
pub completion: String,
pub fallback: String,
}Expand description
Configuration for the models to be used
Fields
suggest: StringThe alias of the AI model to use for generating command suggestions from natural language.
This alias must correspond to a key in the catalog map.
fix: StringThe alias of the AI model used to explain the fix for a failed command.
This alias must correspond to a key in the catalog map.
import: StringThe alias of the AI model to use when importing commands (e.g., from a natural language page).
This alias must correspond to a key in the catalog map.
completion: StringThe alias of the AI model to use when suggesting variable completion commands
This alias must correspond to a key in the catalog map.
fallback: StringThe alias of a model to use as a fallback when the primary model for a task fails due to rate limiting.
This alias must correspond to a key in the catalog map.