pub struct Command {
pub id: Uuid,
pub category: String,
pub source: String,
pub alias: Option<String>,
pub cmd: String,
pub flat_cmd: String,
pub description: Option<String>,
pub flat_description: Option<String>,
pub tags: Option<Vec<String>>,
pub created_at: DateTime<Utc>,
pub updated_at: Option<DateTime<Utc>>,
}Fields
id: UuidUnique identifier for the command
category: StringCategory of the command (user, workspace or tldr’s category)
source: StringCategory of the command (user, ai, tldr, import, workspace)
alias: Option<String>Optional alias for easier recall
cmd: StringThe actual command string, potentially with {{placeholders}}
flat_cmd: StringFlattened version of cmd
description: Option<String>Optional user-provided description
flat_description: Option<String>Flattened version of description
Tags associated with the command (including the hashtag #)
created_at: DateTime<Utc>The date and time when the command was created
updated_at: Option<DateTime<Utc>>The date and time when the command was last updated
Implementations
Sourceimpl Command
impl Command
Sourcepub fn new(
category: impl Into<String>,
source: impl Into<String>,
cmd: impl Into<String>,
) -> Self
pub fn new( category: impl Into<String>, source: impl Into<String>, cmd: impl Into<String>, ) -> Self
Creates a new command, with zero usage
Sourcepub fn with_alias(self, alias: Option<String>) -> Self
pub fn with_alias(self, alias: Option<String>) -> Self
Updates the alias of the command
Sourcepub fn with_description(self, description: Option<String>) -> Self
pub fn with_description(self, description: Option<String>) -> Self
Updates the description (and tags) of the command
Sourcepub fn is_destructive(&self) -> bool
pub fn is_destructive(&self) -> bool
Checks whether the command string contains a destructive shell action.
Sourcepub fn is_destructive_command(command: &str) -> bool
pub fn is_destructive_command(command: &str) -> bool
Checks whether a command string contains a destructive shell action.