pub fn is_destructive(
command: &str,
tags: &[String],
patterns: &[RegexWrapper],
) -> boolExpand description
Checks whether a command string is destructive based on its tags and regex patterns.
pub fn is_destructive(
command: &str,
tags: &[String],
patterns: &[RegexWrapper],
) -> boolChecks whether a command string is destructive based on its tags and regex patterns.