pub fn render_markdown_to_ansi(markdown: &str, theme: &Theme) -> StringExpand description
Renders a markdown string to an ANSI-styled string using the provided theme.
This implementation provides basic support for:
- Headers (styled based on theme comment style, no hashes, underlined for L3/L4)
- Emphasis (bold, italic)
- Lists (bullet points, task lists)
- Code (inline and blocks, styled based on theme accent and secondary styles)
- Paragraphs